@@ -4,13 +4,9 @@ import os
 import sys
 
 from utils import activate_venv, mkdir_p, setenv, run, run_output
-from build_requirements import SWIG
 
 #
 # Driver: tox
-# currently only supports Ubuntu 16.04LTS (xenial), which is the
-# most up-to-date Linux environment available via Travis, and
-# installing many Pythons into it is straightforward
 #
 
 
@@ -19,12 +15,11 @@ def tox_ubuntu_install_buildreqs(MECAB):
     run("sudo", "apt-get", "-y", "update")
 
     packages = [
-        "python2.7-dev", "python3.5-dev", "python3.6-dev",
-        "python3.7-dev", "tox", "swig"
+        "python2.7-dev", "python3.6-dev", "python3.7-dev",
+        "python3.8-dev", "python3.9-dev", "tox"
     ]
     if MECAB == "system":
         packages.append("libmecab-dev")
-        packages.append("mecab-ipadic-utf8")
 
     run("sudo", "apt-get", "-y", "install", *packages)
 
@@ -37,15 +32,15 @@ def tox_build(MECAB, TRAVIS_OS):
         sys.exit(1)
 
     DISTRO = run_output("lsb_release", "-s", "-c")
-    if DISTRO != "xenial":
+    if DISTRO not in ("bionic"):
         sys.stderr.write("Unrecognized Linux distribution: {}\n"
                          .format(DISTRO))
         sys.exit(1)
 
     tox_ubuntu_install_buildreqs(MECAB)
 
-    for snake in ("python2.7", "python3.5", "python3.6", "python3.7"):
-        run(snake, "--version")
+    for snake in ("2.7", "3.6", "3.7", "3.8", "3.9"):
+        run("python" + snake, "--version")
 
     if MECAB == "system":
         run("mecab-config", "--version")
@@ -63,42 +58,7 @@ def cibuildwheel_ubuntu_install_buildreqs():
     run("sudo", "apt-get", "-y", "install", "virtualenv")
 
 
-def cibuildwheel_ubuntu_prep_swig():
-    SWIG.retrieve("build")
-
-
-def cibuildwheel_ubuntu_prep_dictionary():
-    try:
-        with open("/etc/mecabrc", "rt") as fp:
-            for line in fp:
-                if line.startswith("dicdir"):
-                    _, _, dicdir = line.partition("=")
-                    dicdir = dicdir.strip()
-                    break
-            else:
-                raise ValueError("no 'dicdir' line found")
-
-    except (OSError, IOError) as e:
-        sys.stderr.write("* /etc/mecabrc: {}\n", e.strerror())
-        sys.exit(1)
-
-    except Exception as e:
-        sys.stderr.write("* /etc/mecabrc: {}\n", str(e))
-        sys.exit(1)
-
-    # dicdir may be a symlink, force resolution
-    run("cp", "-a", dicdir+"/.", "build/dic")
-
-
 def cibuildwheel_osx_install_buildreqs():
-    # don't waste time on "cleanup"
-    os.environ.pop("HOMEBREW_INSTALL_CLEANUP", None)
-    os.environ["HOMEBREW_NO_INSTALL_CLEANUP"] = "yes"
-
-    # TODO: All calls to brew can probably be removed
-    run("brew", "update")
-    run("brew", "--version")
-    run("brew", "install", "swig")
     run("pip3", "install", "virtualenv")
 
 
@@ -110,14 +70,13 @@ def cibuildwheel_build(MECAB, TRAVIS_OS):
 
     if TRAVIS_OS == "linux":
         DISTRO = run_output("lsb_release", "-s", "-c")
-        if DISTRO != "xenial":
+        if DISTRO not in ("bionic"):
             sys.stderr.write("Unrecognized Linux distribution: {}\n"
                              .format(DISTRO))
             sys.exit(1)
 
         mkdir_p("build")
         cibuildwheel_ubuntu_install_buildreqs()
-        cibuildwheel_ubuntu_prep_swig()
 
     elif TRAVIS_OS == "osx":
         mkdir_p("build")
@@ -145,7 +104,6 @@ def cibuildwheel_build(MECAB, TRAVIS_OS):
 
     S = setenv
     S("CIBW_ENVIRONMENT", "MECAB_DICDIR=build/dic BUNDLE_LIBMECAB=true")
-    S("CIBW_BEFORE_BUILD", "{project}/scripts/cibw-prepare-"+TRAVIS_OS+".py")
     S("CIBW_TEST_COMMAND", "pytest {project}/test/")
     S("CIBW_TEST_REQUIRES", TEST_REQUIRES)
     S("CIBW_BUILD_VERBOSITY", "3")
